==> linkchecker_2.8.orig.tar.gz: linkchecker-2.8.orig/linkcheck/dns/tests/test_rdtypeandclass.py <==
# -*- coding: iso-8859-1 -*-
# Copyright (C) 2003, 2004 Nominum, Inc.
#
# Permission to use, copy, modify, and distribute this software and its
# documentation for any purpose with or without fee is hereby granted,
# provided that the above copyright notice and this permission notice
# appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND NOMINUM DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL NOMINUM BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
# OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

import unittest

import linkcheck.dns.rdataclass
import linkcheck.dns.rdatatype

class TestRdTypeAndClass (unittest.TestCase):

    # Classes

    def test_class_meta1(self):
        self.assert_(linkcheck.dns.rdataclass.is_metaclass(linkcheck.dns.rdataclass.ANY))

    def test_class_meta2(self):
        self.assert_(not linkcheck.dns.rdataclass.is_metaclass(linkcheck.dns.rdataclass.IN))

    def test_class_bytext1(self):
        self.assertEqual(linkcheck.dns.rdataclass.from_text('IN'),
                         linkcheck.dns.rdataclass.IN)

    def test_class_bytext2(self):
        self.assertEqual(linkcheck.dns.rdataclass.from_text('CLASS1'),
                         linkcheck.dns.rdataclass.IN)

    def test_class_bytext_bounds1(self):
        self.assertEqual(linkcheck.dns.rdataclass.from_text('CLASS0'), 0)
        self.assertEqual(linkcheck.dns.rdataclass.from_text('CLASS65535'), 65535)

    def test_class_bytext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdataclass.from_text('CLASS65536')
        self.assertRaises(ValueError, bad)

    def test_class_bytext_unknown(self):
        def bad():
            junk = linkcheck.dns.rdataclass.from_text('XXX')
        self.assertRaises(linkcheck.dns.rdataclass.UnknownRdataclass, bad)

    def test_class_totext1(self):
        self.assertEqual(linkcheck.dns.rdataclass.to_text(linkcheck.dns.rdataclass.IN),
                         'IN')

    def test_class_totext1(self):
        self.assertEqual(linkcheck.dns.rdataclass.to_text(999), 'CLASS999')

    def test_class_totext_bounds1(self):
        def bad():
            junk = linkcheck.dns.rdataclass.to_text(-1)
        self.assertRaises(ValueError, bad)

    def test_class_totext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdataclass.to_text(65536)
        self.assertRaises(ValueError, bad)

    # Types

    def test_type_meta1(self):
        self.assert_(linkcheck.dns.rdatatype.is_metatype(linkcheck.dns.rdatatype.ANY))

    def test_type_meta2(self):
        self.assert_(linkcheck.dns.rdatatype.is_metatype(linkcheck.dns.rdatatype.OPT))

    def test_type_meta3(self):
        self.assert_(not linkcheck.dns.rdatatype.is_metatype(linkcheck.dns.rdatatype.A))

    def test_type_singleton1(self):
        self.assert_(linkcheck.dns.rdatatype.is_singleton(linkcheck.dns.rdatatype.SOA))

    def test_type_singleton2(self):
        self.assert_(not linkcheck.dns.rdatatype.is_singleton(linkcheck.dns.rdatatype.A))

    def test_type_bytext1(self):
        self.assertEqual(linkcheck.dns.rdatatype.from_text('A'), linkcheck.dns.rdatatype.A)

    def test_type_bytext2(self):
        self.assertEqual(linkcheck.dns.rdatatype.from_text('TYPE1'),
                         linkcheck.dns.rdatatype.A)

    def test_type_bytext_bounds1(self):
        self.assertEqual(linkcheck.dns.rdatatype.from_text('TYPE0'), 0)
        self.assertEqual(linkcheck.dns.rdatatype.from_text('TYPE65535'), 65535)

    def test_type_bytext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdatatype.from_text('TYPE65536')
        self.assertRaises(ValueError, bad)

    def test_type_bytext_unknown(self):
        def bad():
            junk = linkcheck.dns.rdatatype.from_text('XXX')
        self.assertRaises(linkcheck.dns.rdatatype.UnknownRdatatype, bad)

    def test_type_totext1(self):
        self.assertEqual(linkcheck.dns.rdatatype.to_text(linkcheck.dns.rdatatype.A), 'A')

    def test_type_totext1(self):
        self.assertEqual(linkcheck.dns.rdatatype.to_text(999), 'TYPE999')

    def test_type_totext_bounds1(self):
        def bad():
            junk = linkcheck.dns.rdatatype.to_text(-1)
        self.assertRaises(ValueError, bad)

    def test_type_totext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdatatype.to_text(65536)
        self.assertRaises(ValueError, bad)


def test_suite ():
    suite = unittest.TestSuite()
    suite.addTest(unittest.makeSuite(TestRdTypeAndClass))
    return suite


if __name__ == '__main__':
    unittest.main()

==> linkchecker_3.1.orig.tar.gz: linkchecker-3.1.orig/linkcheck/dns/tests/test_rdtypeandclass.py <==
# -*- coding: iso-8859-1 -*-
# Copyright (C) 2003, 2004 Nominum, Inc.
#
# Permission to use, copy, modify, and distribute this software and its
# documentation for any purpose with or without fee is hereby granted,
# provided that the above copyright notice and this permission notice
# appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND NOMINUM DISCLAIMS ALL WARRANTIES
# WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
# MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL NOMINUM BE LIABLE FOR
# ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
# WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
# ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT
# OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

import unittest

import linkcheck.dns.rdataclass
import linkcheck.dns.rdatatype

class TestRdTypeAndClass (unittest.TestCase):

    # Classes

    def test_class_meta1(self):
        self.assert_(linkcheck.dns.rdataclass.is_metaclass(linkcheck.dns.rdataclass.ANY))

    def test_class_meta2(self):
        self.assert_(not linkcheck.dns.rdataclass.is_metaclass(linkcheck.dns.rdataclass.IN))

    def test_class_bytext1(self):
        self.assertEqual(linkcheck.dns.rdataclass.from_text('IN'),
                         linkcheck.dns.rdataclass.IN)

    def test_class_bytext2(self):
        self.assertEqual(linkcheck.dns.rdataclass.from_text('CLASS1'),
                         linkcheck.dns.rdataclass.IN)

    def test_class_bytext_bounds1(self):
        self.assertEqual(linkcheck.dns.rdataclass.from_text('CLASS0'), 0)
        self.assertEqual(linkcheck.dns.rdataclass.from_text('CLASS65535'), 65535)

    def test_class_bytext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdataclass.from_text('CLASS65536')
        self.assertRaises(ValueError, bad)

    def test_class_bytext_unknown(self):
        def bad():
            junk = linkcheck.dns.rdataclass.from_text('XXX')
        self.assertRaises(linkcheck.dns.rdataclass.UnknownRdataclass, bad)

    def test_class_totext1(self):
        self.assertEqual(linkcheck.dns.rdataclass.to_text(linkcheck.dns.rdataclass.IN),
                         'IN')

    def test_class_totext1(self):
        self.assertEqual(linkcheck.dns.rdataclass.to_text(999), 'CLASS999')

    def test_class_totext_bounds1(self):
        def bad():
            junk = linkcheck.dns.rdataclass.to_text(-1)
        self.assertRaises(ValueError, bad)

    def test_class_totext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdataclass.to_text(65536)
        self.assertRaises(ValueError, bad)

    # Types

    def test_type_meta1(self):
        self.assert_(linkcheck.dns.rdatatype.is_metatype(linkcheck.dns.rdatatype.ANY))

    def test_type_meta2(self):
        self.assert_(linkcheck.dns.rdatatype.is_metatype(linkcheck.dns.rdatatype.OPT))

    def test_type_meta3(self):
        self.assert_(not linkcheck.dns.rdatatype.is_metatype(linkcheck.dns.rdatatype.A))

    def test_type_singleton1(self):
        self.assert_(linkcheck.dns.rdatatype.is_singleton(linkcheck.dns.rdatatype.SOA))

    def test_type_singleton2(self):
        self.assert_(not linkcheck.dns.rdatatype.is_singleton(linkcheck.dns.rdatatype.A))

    def test_type_bytext1(self):
        self.assertEqual(linkcheck.dns.rdatatype.from_text('A'), linkcheck.dns.rdatatype.A)

    def test_type_bytext2(self):
        self.assertEqual(linkcheck.dns.rdatatype.from_text('TYPE1'),
                         linkcheck.dns.rdatatype.A)

    def test_type_bytext_bounds1(self):
        self.assertEqual(linkcheck.dns.rdatatype.from_text('TYPE0'), 0)
        self.assertEqual(linkcheck.dns.rdatatype.from_text('TYPE65535'), 65535)

    def test_type_bytext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdatatype.from_text('TYPE65536')
        self.assertRaises(ValueError, bad)

    def test_type_bytext_unknown(self):
        def bad():
            junk = linkcheck.dns.rdatatype.from_text('XXX')
        self.assertRaises(linkcheck.dns.rdatatype.UnknownRdatatype, bad)

    def test_type_totext1(self):
        self.assertEqual(linkcheck.dns.rdatatype.to_text(linkcheck.dns.rdatatype.A), 'A')

    def test_type_totext1(self):
        self.assertEqual(linkcheck.dns.rdatatype.to_text(999), 'TYPE999')

    def test_type_totext_bounds1(self):
        def bad():
            junk = linkcheck.dns.rdatatype.to_text(-1)
        self.assertRaises(ValueError, bad)

    def test_type_totext_bounds2(self):
        def bad():
            junk = linkcheck.dns.rdatatype.to_text(65536)
        self.assertRaises(ValueError, bad)


def test_suite ():
    return unittest.makeSuite(TestRdTypeAndClass)


if __name__ == '__main__':
    unittest.main()
